@@ -31,7 +31,7 @@ test_that("printing", {
   ', invisible=TRUE)
   expect_equal(capture.output(f()),"Hi everybody")
   f <- rust_fn('
-      Rval::new(rprintln!("Washington"), &mut pc)
+      Rval::new(rprintln!("Washington"), pc)
   ')
   output <- capture.output(interrupted <- f())
   expect_equal(interrupted,FALSE)
@@ -55,17 +55,17 @@ test_that("longjmp", {
 
 test_that("f64", {
   f1 <- rust_fn(a, '
-      Rval::new(f64::from(a), &mut pc)
+      Rval::new(f64::from(a), pc)
   ')
   f2 <- rust_fn(a, '
-      Rval::new(f64::from(a), &mut pc)
+      Rval::new(f64::from(a), pc)
   ')
   f3 <- rust_fn(a, '
       let b: f64 = a.into();
-      Rval::new(b, &mut pc)
+      Rval::new(b, pc)
   ')
   f4 <- rust_fn(a, '
-      Rval::new(a.as_f64(), &mut pc)
+      Rval::new(a.as_f64(), pc)
   ')
   for ( f in list(f1,f2,f3,f4) ) {
     expect_equal(f(7), 7)
@@ -85,17 +85,17 @@ test_that("f64", {
 
 test_that("i32", {
   f1 <- rust_fn(a, '
-      Rval::new(i32::from(a), &mut pc)
+      Rval::new(i32::from(a), pc)
   ')
   f2 <- rust_fn(a, '
-      Rval::new(i32::from(a), &mut pc)
+      Rval::new(i32::from(a), pc)
   ')
   f3 <- rust_fn(a, '
       let b: i32 = a.into();
-      Rval::new(b, &mut pc)
+      Rval::new(b, pc)
   ')
   f4 <- rust_fn(a, '
-      Rval::new(a.as_i32(), &mut pc)
+      Rval::new(a.as_i32(), pc)
   ')
   for ( f in list(f1,f2,f3) ) {
     expect_equal(f(7), 7L)
@@ -115,16 +115,16 @@ test_that("i32", {
 test_that("bool", {
   f1 <- rust_fn(a, '
       use std::convert::TryFrom;
-      Rval::new(bool::try_from(a).unwrap(), &mut pc)
+      Rval::new(bool::try_from(a).unwrap(), pc)
   ')
   f2 <- rust_fn(a, '
-      Rval::new(a.is_true(), &mut pc)
+      Rval::new(a.is_true(), pc)
   ')
   f3 <- rust_fn(a, '
-      Rval::new(a.is_true(), &mut pc)
+      Rval::new(a.is_true(), pc)
   ')
   f4 <- rust_fn(a, '
-      Rval::new(a.as_bool(), &mut pc)
+      Rval::new(a.as_bool(), pc)
   ')
   for ( f in list(f1,f2,f3) ) {
     expect_equal(f(7), TRUE)
@@ -143,7 +143,7 @@ test_that("bool", {
 test_that("usize", {
   f1 <- rust_fn(a, '
       use std::convert::TryFrom;
-      Rval::try_new(usize::try_from(a).unwrap(), &mut pc).unwrap()
+      Rval::try_new(usize::try_from(a).unwrap(), pc).unwrap()
   ')
   for ( f in list(f1) ) {
     expect_equal(f(7), 7L)
@@ -156,13 +156,13 @@ test_that("usize", {
     expect_equal(f(TRUE), 1L)
   }
   f <- rust_fn(a, '
-      Rval::try_new(a.as_usize(), &mut pc).unwrap()
+      Rval::try_new(a.as_usize(), pc).unwrap()
   ')
   expect_equal(f(5), 5L)
   expect_equal(f(TRUE), 1L)
   expect_equal(f(-5), 0L)
   f <- rust_fn(a, '
-    Rval::try_new(a.as_usize(), &mut pc).unwrap()
+    Rval::try_new(a.as_usize(), pc).unwrap()
   ')
   expect_equal(f(7), 7L)
   expect_equal(f(-7), 0L)
@@ -181,67 +181,67 @@ test_that("Special values", {
   ')
   expect_equal(f(), NULL)
   f <- rust_fn('
-    Rval::new(Rval::nan(), &mut pc)
+    Rval::new(Rval::nan(), pc)
   ')
   expect_equal(f(), NaN)
   f <- rust_fn('
-    Rval::new(Rval::na_double(), &mut pc)
+    Rval::new(Rval::na_double(), pc)
   ')
   expect_equal(f(), NA_real_)
   f <- rust_fn('
-    Rval::new(Rval::na_integer(), &mut pc)
+    Rval::new(Rval::na_integer(), pc)
   ')
   expect_equal(f(), NA_integer_)
   f <- rust_fn('
-    Rval::new(Rval::na_logical(), &mut pc)
+    Rval::new(Rval::na_logical(), pc)
   ')
   expect_equal(f(), NA_integer_)
   f <- rust_fn(b, '
-    Rval::new(Rval::na_character().0 == b.get_character_element(0).0, &mut pc)
+    Rval::new(Rval::na_character().0 == b.get_character_element(0).0, pc)
   ')
   expect_true(f(NA_character_))
   f <- rust_fn('
-    Rval::new(Rval::infinity_positive(), &mut pc)
+    Rval::new(Rval::infinity_positive(), pc)
   ')
   expect_equal(f(), Inf)
   expect_true(is.infinite(f()))
   f <- rust_fn('
-    Rval::new(Rval::infinity_negative(), &mut pc)
+    Rval::new(Rval::infinity_negative(), pc)
   ')
   expect_equal(f(), -Inf)
   expect_true(is.infinite(f()))
   f <- rust_fn(a, '
-    Rval::new(Rval::is_finite(a.as_f64()), &mut pc)
+    Rval::new(Rval::is_finite(a.as_f64()), pc)
   ')
   expect_true(f(1.0))
   expect_false(f(Inf))
   expect_false(f(-Inf))
   f <- rust_fn(a, '
-    Rval::new(Rval::is_nan(a.as_f64()), &mut pc)
+    Rval::new(Rval::is_nan(a.as_f64()), pc)
   ')
   expect_true(f(NaN))
   expect_false(f(1.0))
   expect_false(f(NA))
   f <- rust_fn(a, '
-    Rval::new(Rval::is_na_double(a.as_f64()), &mut pc)
+    Rval::new(Rval::is_na_double(a.as_f64()), pc)
   ')
   expect_false(f(NaN))
   expect_false(f(1.0))
   expect_true(f(NA))
   f <- rust_fn(a, '
-    Rval::new(Rval::is_na_integer(a.as_i32()), &mut pc)
+    Rval::new(Rval::is_na_integer(a.as_i32()), pc)
   ')
   expect_false(f(1L))
   expect_true(f(NA))
   f <- rust_fn(a, '
     let b = a.slice_logical().unwrap();
-    Rval::new(Rval::is_na_logical(b[0]), &mut pc)
+    Rval::new(Rval::is_na_logical(b[0]), pc)
   ')
   expect_true(f(NA))
   expect_false(f(TRUE))
   expect_false(f(FALSE))
   f <- rust_fn(a, '
-    Rval::new(Rval::is_na_character(a.get_character_element(0)), &mut pc)
+    Rval::new(Rval::is_na_character(a.get_character_element(0)), pc)
   ')
   a <- NA
   storage.mode(a) <- "character"
@@ -253,7 +253,7 @@ test_that("f64 slice", {
   f1 <- rust_fn(a, '
       use std::convert::TryInto;
       let b: &[f64] = a.try_into().unwrap();
-      Rval::new(b, &mut pc)
+      Rval::new(b, pc)
   ')
   f2 <- rust_fn(a, '
       use std::convert::TryInto;
@@ -261,15 +261,15 @@ test_that("f64 slice", {
       if b.is_err() {
         panic!("Oops, not a double vector")
       }
-      Rval::new(b.unwrap(), &mut pc)
+      Rval::new(b.unwrap(), pc)
   ')
   f3 <- rust_fn(a, '
       use std::convert::TryFrom;
       let b = <&[f64]>::try_from(a).unwrap();
-      Rval::new(b, &mut pc)
+      Rval::new(b, pc)
   ')
   f4 <- rust_fn(a, '
-      Rval::new(a.slice_double().unwrap(), &mut pc)
+      Rval::new(a.slice_double().unwrap(), pc)
   ')
   for ( f in list(f1,f2,f3,f4) ) {
     expect_equal(f(7), 7)
@@ -279,11 +279,11 @@ test_that("f64 slice", {
     expect_error(f(c(1L,2L)))
   }
   f1 <- rust_fn(a, '
-      let b = a.coerce_double(&mut pc).unwrap().1;
-      Rval::new(b, &mut pc)
+      let b = a.coerce_double(pc).unwrap().1;
+      Rval::new(b, pc)
   ')
   f2 <- rust_fn(a, '
-      a.coerce_double(&mut pc).unwrap().0
+      a.coerce_double(pc).unwrap().0
   ')
   for ( f in list(f1, f2) ) {
     expect_equal(f(7), 7)
@@ -294,20 +294,20 @@ test_that("f64 slice", {
   }
   f1 <- rust_fn('
       let data = [3.0, 4.5, 6.1];
-      let (rval, slice) = Rval::new_vector_double(data.len(), &mut pc);
+      let (rval, slice) = Rval::new_vector_double(data.len(), pc);
       slice.copy_from_slice(&data[..]);
       rval
   ')
   f <- f1
   expect_equal(f(), c(3, 4.5, 6.1))
   f1 <- rust_fn('
-      Rval::new([3.0, 4.5, 6.1], &mut pc)
+      Rval::new([3.0, 4.5, 6.1], pc)
   ')
   f <- f1
   expect_equal(f(), c(3, 4.5, 6.1))
   f1 <- rust_fn('
       let a = [3.0, 4.5, 6.1];
-      Rval::new(&a[..], &mut pc)
+      Rval::new(&a[..], pc)
   ')
   f <- f1
   expect_equal(f(), c(3, 4.5, 6.1))
@@ -317,7 +317,7 @@ test_that("i32 slice", {
   f1 <- rust_fn(a, '
       use std::convert::TryInto;
       let b: &[i32] = a.try_into().unwrap();
-      Rval::new(b, &mut pc)
+      Rval::new(b, pc)
   ')
   f2 <- rust_fn(a, '
       use std::convert::TryInto;
@@ -325,15 +325,15 @@ test_that("i32 slice", {
       if b.is_err() {
           panic!("Oops, not an integer vector")
       }
-      Rval::new(b.unwrap(), &mut pc)
+      Rval::new(b.unwrap(), pc)
   ')
   f3 <- rust_fn(a, '
       use std::convert::TryFrom;
       let b = <&[i32]>::try_from(a).unwrap();
-      Rval::new(b, &mut pc)
+      Rval::new(b, pc)
   ')
   f4 <- rust_fn(a, '
-      Rval::new(a.slice_integer().unwrap(), &mut pc)
+      Rval::new(a.slice_integer().unwrap(), pc)
   ')
   for ( f in list(f1,f2,f3,f4) ) {
     expect_equal(f(7L), 7L)
@@ -343,11 +343,11 @@ test_that("i32 slice", {
     expect_error(f(c(1, 2)))
   }
   f1 <- rust_fn(a, '
-      let b = a.coerce_integer(&mut pc).unwrap().1;
-      Rval::new(b, &mut pc)
+      let b = a.coerce_integer(pc).unwrap().1;
+      Rval::new(b, pc)
   ')
   f2 <- rust_fn(a, '
-      a.coerce_integer(&mut pc).unwrap().0
+      a.coerce_integer(pc).unwrap().0
   ')
   for ( f in list(f1, f2) ) {
     expect_equal(f(7), 7L)
@@ -358,90 +358,90 @@ test_that("i32 slice", {
   }
   f1 <- rust_fn('
       let data = [3, 4, 6];
-      let (rval, slice) = Rval::new_vector_integer(data.len(), &mut pc);
+      let (rval, slice) = Rval::new_vector_integer(data.len(), pc);
       slice.copy_from_slice(&data[..]);
       rval
   ')
   f <- f1
   expect_equal(f(), c(3L, 4L, 6L))
   f1 <- rust_fn('
-      Rval::new([3, 4, 6], &mut pc)
+      Rval::new([3, 4, 6], pc)
   ')
   f <- f1
   expect_equal(f(), c(3L, 4L, 6L))
   f1 <- rust_fn('
       let a = [3, 4, 6];
-      Rval::new(&a[..], &mut pc)
+      Rval::new(&a[..], pc)
   ')
   f <- f1
   expect_equal(f(), c(3L, 4L, 6L))
 })
 
 test_that("vectors", {
-  f <- rust_fn(len, 'Rval::new_vector_double(len.as_usize(), &mut pc).0')
+  f <- rust_fn(len, 'Rval::new_vector_double(len.as_usize(), pc).0')
   expect_true(is.double(f(4)))
   expect_equal(length(f(0)),0)
   expect_equal(length(f(5)),5)
-  f <- rust_fn(len, 'Rval::new_vector_integer(len.as_usize(), &mut pc).0')
+  f <- rust_fn(len, 'Rval::new_vector_integer(len.as_usize(), pc).0')
   expect_true(is.integer(f(4)))
   expect_equal(length(f(0)),0)
   expect_equal(length(f(5)),5)
-  f <- rust_fn(len, 'Rval::new_vector_logical(len.as_usize(), &mut pc).0')
+  f <- rust_fn(len, 'Rval::new_vector_logical(len.as_usize(), pc).0')
   expect_true(is.logical(f(4)))
   expect_equal(length(f(0)),0)
   expect_equal(length(f(5)),5)
-  f <- rust_fn(len, 'Rval::new_vector_raw(len.as_usize(), &mut pc).0')
+  f <- rust_fn(len, 'Rval::new_vector_raw(len.as_usize(), pc).0')
   expect_true(is.raw(f(4)))
   expect_equal(length(f(0)),0)
   expect_equal(length(f(5)),5)
-  f <- rust_fn(len, 'Rval::new_vector_character(len.as_usize(), &mut pc)')
+  f <- rust_fn(len, 'Rval::new_vector_character(len.as_usize(), pc)')
   expect_true(is.character(f(4)))
   expect_equal(length(f(0)),0)
   expect_equal(length(f(5)),5)
   f <- rust_fn('
-      let a = Rval::new_vector_character(1, &mut pc);
-      a.set_character_element(0, "David");
-      a.set_character_element(1, "Lisa");
+      let a = Rval::new_vector_character(1, pc);
+      a.set_character_element(0, "David", pc);
+      a.set_character_element(1, "Lisa", pc);
       a
   ')
   expect_error(f())
   f <- rust_fn('
-      let a = Rval::new_vector_character(2, &mut pc);
-      a.set_character_element(0, "David");
-      a.set_character_element(1, "Lisa");
+      let a = Rval::new_vector_character(2, pc);
+      a.set_character_element(0, "David", pc);
+      a.set_character_element(1, "Lisa", pc);
       a
   ')
   expect_equal(f(),c("David","Lisa"))
-  f <- rust_fn('Rval::new(["David", "Lisa"], &mut pc)')
+  f <- rust_fn('Rval::new(["David", "Lisa"], pc)')
   expect_equal(f(),c("David","Lisa"))
-  f <- rust_fn('let a = ["David", "Lisa"]; Rval::new(&a[..], &mut pc)')
+  f <- rust_fn('let a = ["David", "Lisa"]; Rval::new(&a[..], pc)')
   expect_equal(f(),c("David","Lisa"))
 })
 
 test_that("data.frame", {
-  f <- rust_fn(x, 'Rval::new(x.is_data_frame(), &mut pc)')
+  f <- rust_fn(x, 'Rval::new(x.is_data_frame(), pc)')
   expect_true(f(data.frame(x=1:2,y=4:5)))
   expect_false(f(matrix(1:4, nrow=2)))
 })
 
 test_that("matrices", {
-  f <- rust_fn(nrow, ncol, 'Rval::new_matrix_double(nrow.as_usize(),ncol.as_usize(), &mut pc).0')
+  f <- rust_fn(nrow, ncol, 'Rval::new_matrix_double(nrow.as_usize(),ncol.as_usize(), pc).0')
   expect_equal(dim(f(2,3)),c(2,3))
   expect_equal(dim(f(-2,3)),c(0,3))
   expect_true(is.double(f(2,3)))
-  f <- rust_fn(nrow, ncol, 'Rval::new_matrix_integer(nrow.as_usize(),ncol.as_usize(), &mut pc).0')
+  f <- rust_fn(nrow, ncol, 'Rval::new_matrix_integer(nrow.as_usize(),ncol.as_usize(), pc).0')
   expect_equal(dim(f(2,3)),c(2,3))
   expect_equal(dim(f(-2,-3)),c(0,0))
   expect_true(is.integer(f(2,3)))
-  f <- rust_fn(nrow, ncol, 'Rval::new_matrix_logical(nrow.as_usize(),ncol.as_usize(), &mut pc).0')
+  f <- rust_fn(nrow, ncol, 'Rval::new_matrix_logical(nrow.as_usize(),ncol.as_usize(), pc).0')
   expect_equal(dim(f(2,3)),c(2,3))
   expect_equal(dim(f(2,-3)),c(2,0))
   expect_true(is.logical(f(2,3)))
-  f <- rust_fn(nrow, ncol, 'Rval::new_matrix_character(nrow.as_usize(),ncol.as_usize(), &mut pc)')
+  f <- rust_fn(nrow, ncol, 'Rval::new_matrix_character(nrow.as_usize(),ncol.as_usize(), pc)')
   expect_equal(dim(f(2,3)),c(2,3))
   expect_equal(dim(f(-2,3)),c(0,3))
   expect_true(is.character(f(2,3)))
-  f <- rust_fn(x, 'x.transpose(&mut pc)')
+  f <- rust_fn(x, 'x.transpose(pc)')
   x <- matrix(1:6, nrow=3)
   expect_identical(t(x), f(x))
   x <- matrix(as.character(1:12), nrow=3)
@@ -449,13 +449,13 @@ test_that("matrices", {
 })
 
 test_that("lists", {
-  f <- rust_fn(len, 'Rval::new_list(len.as_usize(), &mut pc)')
+  f <- rust_fn(len, 'Rval::new_list(len.as_usize(), pc)')
   expect_true(is.list(f(4)))
   expect_equal(length(f(0)),0)
   expect_equal(length(f(5)),5)
   f <- rust_fn('
-      let result = Rval::new_list(1, &mut pc);
-      result.set_list_element(1, Rval::new(1, &mut pc));
+      let result = Rval::new_list(1, pc);
+      result.set_list_element(1, Rval::new(1, pc));
       result
   ')
   expect_error(f())
@@ -463,12 +463,12 @@ test_that("lists", {
 
 test_that("attr", {
   f <- rust_fn(a,'
-      a.set_attribute("names", Rval::new(["name","age"], &mut pc), &mut pc);
+      a.set_attribute("names", Rval::new(["name","age"], pc), pc);
       a
   ')
   expect_equal(f(c("Sally","17")),c(name="Sally", age="17"))
   f <- rust_fn(a,'
-      a.get_attribute("names", &mut pc)
+      a.get_attribute("names", pc)
   ')
   x <- c(name="Sally", age="17")
   expect_equal(f(x),names(x))
@@ -476,7 +476,7 @@ test_that("attr", {
 
 test_that("names_gets", {
   f <- rust_fn(a,'
-      a.names_gets(Rval::new(["name","age"], &mut pc));
+      a.names_gets(Rval::new(["name","age"], pc));
       a
   ')
   expect_equal(f(c("Sally","17")),c(name="Sally", age="17"))
@@ -487,14 +487,14 @@ test_that("names_gets", {
 
 test_that("class_gets", {
   f <- rust_fn(a,'
-      a.class_gets(Rval::new(["dog","animal"], &mut pc));
+      a.class_gets(Rval::new(["dog","animal"], pc));
       a
   ')
   expect_true(inherits(f(c("Sally","17")), "dog"))
   expect_true(inherits(f(c("Sally","17")), "animal"))
   expect_false(inherits(f(c("Sally","17")), "cat"))
   f <- rust_fn(a,'
-      a.class_gets(Rval::new([234], &mut pc));
+      a.class_gets(Rval::new([234], pc));
       a
   ')
   expect_error(f(list("Sally",17)))
@@ -504,7 +504,7 @@ test_that("class_gets", {
 
 test_that("len", {
   f <- rust_fn(a,'
-      Rval::try_new(a.len(), &mut pc).unwrap()
+      Rval::try_new(a.len(), pc).unwrap()
   ')
   expect_equal(f(NA),1)
   expect_equal(f(c()),0)
@@ -513,18 +513,18 @@ test_that("len", {
 })
 
 test_that("call", {
-  f <- rust_fn(a,'a.call0(&mut pc).unwrap()')
+  f <- rust_fn(a,'a.call0(pc).unwrap()')
   expect_equal(f(function() 4),4)
   expect_false(f(function() 4) == 3)
   expect_false(f(function() 4) == 3)
-  f <- rust_fn(a,'Rval::new(a.call0(&mut pc).is_err(), &mut pc)')
+  f <- rust_fn(a,'Rval::new(a.call0(pc).is_err(), pc)')
   errfn <- function() stop("An error was thrown!")
   expect_true(f(errfn))
 })
 
 test_that("string", {
   f <- rust_fn(a,'
-      Rval::new(a.as_string(), &mut pc)
+      Rval::new(a.as_string(), pc)
   ')
   expect_equal(f(c("David")),"David")
   expect_equal(f(c("David","Lisa")),"David")
